

``zaya`` is a toolbox for the https://zaya.io community.


Install
-------

    pip3 install zaya


Usage
-------------

    import zaya


get Information from zaya
-------

> zaya.__author__

> zaya.__website__

> zaya.__version__